/**
 * @module
 * @license MIT
 * @author Sébastien Règne
 */
/**
 * @typedef {NodeJS.WritableStream} WritableStream
 * @typedef {import("../../types").Notice} Notice
 */
/**
 * Le formateur qui écrit les résultats dans un format simple : une notification
 * par ligne.
 */
export const Formatter: {
    new (level: number, writer: WritableStream): {
        /**
         * Le niveau de sévérité minimum des notifications affichées.
         *
         * @type {number}
         */
        "__#6@#level": number;
        /**
         * Le flux où écrire les résultats.
         *
         * @type {WritableStream}
         */
        "__#6@#writer": WritableStream;
        /**
         * La marque indiquant si c'est la première ligne qui est affichée.
         *
         * @type {boolean}
         */
        "__#6@#first": boolean;
        /**
         * Affiche les éventuelles notifications d'un fichier.
         *
         * @param {string}             file    Le fichier analysé.
         * @param {Notice[]|undefined} notices La liste des notifications ou
         *                                     <code>undefined</code>.
         */
        notify(file: string, notices: Notice[] | undefined): void;
        /**
         * Finalise l'affichage.
         *
         * @returns {Promise<void>} La promesse indiquant que tous les textes sont
         *                          écrits.
         */
        finalize(): Promise<void>;
    };
};
export type WritableStream = NodeJS.WritableStream;
export type Notice = import("../../types").Notice;
